{% load i18n %}

{% if current_page.has_previous or current_page.has_next %}
<fieldset class="ui-grid-a">
    <div class="ui-block-a">
        {% if current_page.has_previous %}<a href="?page={{ current_page.previous_page_number }}&{{ querystring }}" data-role="button" data-icon="arrow-l" data-iconpos="left">{% trans "Previous" %}</a>{% endif %}
    </div>
    <div class="ui-block-b">
	    {% if current_page.has_next %}<a href="?page={{ current_page.next_page_number }}&{{ querystring }}" data-role="button" data-icon="arrow-r" data-iconpos="right">{% trans "Next" %}</a>{% endif %}
    </div>
</fieldset>
{% endif %}