{% load i18n mezzanine_tags comment_tags %}
<div id="comments">
<h3>{% trans "Comments" %}</h3>
{% if settings.COMMENTS_DISQUS_SHORTNAME %}
{% include "generic/includes/disqus_comments.html" %}
{% else %}
<script>
$(function() {
    $('.reply').click(function() {
        $(this).next('.reply-form').toggle();
    });
});
</script>
<style>.input_id_honeypot {display:none !important;}</style>
{% comment_thread object_for_comments %}
<h3>{% trans "New Comment" %}</h3>
<form method="post" id="comment" action="{{ comment_url }}#comment">
    {% if not request.POST.replied_to %}
    {% fields_for posted_comment_form %}
    {% else %}
    {% fields_for unposted_comment_form %}
    {% endif %}
    <div class="form-actions">
        <input class="btn btn-primary btn-large" type="submit" value="{% trans "Send" %}">
    </div>
</form>
{% endif %}
</div>
