{% extends "email/base.html" %}

{% block main %}
{% if message %}<p>{{ message }}</p>{% endif %}
<table border="0">
{% for field, value in fields %}
<tr>
    <td><b>{{ field }}:</b></td>
    <td>{{ value }}</td>
</tr>
{% endfor %}
</table>
{% endblock %}
