{% load i18n %}
{% block main %}
<p>{% trans "Hey there, the password reset form was used for your account." %}</p>
<p>{% trans "Please use the link below to log in and update your password." %}</p>
<p><a href="http://{{ request.get_host }}{{ verify_url }}">http://{{ request.get_host }}{{ verify_url }}</a></p>
<p>{% trans "If you didn't request for your password to be reset, please ignore this email." %}</p>
{% endblock %}

