{% load i18n %}

{# Edit form #}
<form style="display:none;" class="editable-form" method="post"
    action="{% url edit %}" id="{{ form.uuid }}"
    {% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
    {% csrf_token %}
    {% for field in form %}
    <p{% if field.is_hidden %} style="display:none;"{% endif %}>
        {{ field.label_tag }}<br />{{ field }}{{ field.errors }}
        {% if field.help_text %}
        <span class="helptext">{{ field.help_text }}</span>
        {% endif %}
    </p>
    {% endfor %}
    <input type="submit" value="{% trans "Save" %}" class="btn primary large">
    <input type="button" value="{% trans "Cancel" %}" class="btn large">
</form>

{# Original content wrapped in span #}
<div class="editable-original">{{ original }}</div>

{# Edit link #}
<a style="display:none;" class="editable-link" href="#"
    rel="#{{ form.uuid }}">{% trans "Edit" %}</a>

{# Edit highlight #}
<div style="display:none;" class="editable-highlight"></div>

