{% extends "pages/page.html" %}

{% load mezzanine_tags %}

{% block main %}{{ block.super }}

{% editable page.richtextpage.content %}
{{ page.richtextpage.content|richtext_filter|safe }}
{% endeditable %}

{% endblock %}
