{% extends "accounts/account_form.html" %}
{% load i18n %}

{% block main %}
{{ block.super }}
<p>{% trans "Enter your username or email address and you'll receive an email with a link you need to click, in order to log in and change your password." %}</p>
{% endblock %}


