{% extends "admin/base_site.html" %}

{% load i18n mezzanine_tags %}

{% block extrahead %}
{{ block.super }}
<link rel="stylesheet" href="{% load adminmedia %}{% admin_media_prefix %}css/dashboard.css" />
<link rel="stylesheet" href="{{ STATIC_URL }}mezzanine/css/admin/dashboard.css">
<!--[if IE 7]><style>.dashboard #content {padding-top: 80px;}</style><![endif]-->
{% endblock %}

{% block coltype %}colMS{% endblock %}
{% block bodyclass %}dashboard{% endblock %}

{% block breadcrumbs %}<div class="breadcrumbs">{% trans "Home" %}</div>{% endblock %}

{% block content_title %}<h1>{% trans "Dashboard" %}</h1>{% endblock %}

{% block content %}<div id="content-main">{% dashboard_column 0 %}</div>{% endblock %}

{% block sidebar %}
    <div id="content-related" class="dashboard1">{% dashboard_column 2 %}</div>
    {% block extendedsidebar %}
    <div id="content-related" class="dashboard2">{% dashboard_column 1 %}</div>
    {% endblock %}
{% endblock %}
