nav { margin-top: 0; }

.since, .help { font-size: 11px; }

.editable-original h2 { margin-top: 0; margin-bottom: 0; }

.share-links { margin-top: 10px; }

.comments { list-style: none; }
#comment th { vertical-align: top; }

.tags ul {padding:0;}
.tags ul, .tags li { list-style: none; display:inline;}
