{% extends "accounts/account_form.html" %}
{% load i18n %}

{% block main %}

{% if request.user.is_authenticated %}
    <p>{% trans "You're already logged in." %}</p>
{% else %}
    {{ block.super }}
    {% url signup as signup_url %}
    <p>{% blocktrans with request.GET.next as next %}If you don't have an acount you can <a href="{{ signup_url }}?next={{ next }}">sign up</a> for one now.{% endblocktrans %}</p>
    {% url mezzanine_password_reset as password_reset_url %}
    {% url profile_update as profile_update_url %}
    {% blocktrans %}<p>You can also <a href="{{ password_reset_url }}?next={{ profile_update_url }}">reset your password</a> if you've forgotten it.</p>{% endblocktrans %}</p>
{% endif %}

{% endblock %}

