{% extends "blog/blog_post_list.html" %}
{% load mezzanine_tags comment_tags keyword_tags rating_tags i18n %}

{% block meta_title %}{{ blog_post.meta_title }}{% endblock %}

{% block meta_keywords %}{% metablock %}
{% keywords_for blog_post as tags %}
{% for tag in tags %}{% if not forloop.first %}, {% endif %}{{ tag }}{% endfor %}
{% endmetablock %}{% endblock %}

{% block meta_description %}{% metablock %}
{{ blog_post.description }}
{% endmetablock %}{% endblock %}

{% block title %}
{% editable blog_post.title %}{{ blog_post.title }}{% endeditable %}
{% endblock %}

{% block breadcrumb_menu %}
{{ block.super }}
<li class="active">{{ blog_post.title }}</li>
{% endblock %}

{% block main %}

<h6>
    {% trans "Posted by" %}:
    {% with blog_post.user as author %}
    <a href="{% url blog_post_list_author author %}">{{ author.get_full_name|default:author.username }}</a>
    {% endwith %}
    {{ blog_post.publish_date|timesince }} {% trans "ago" %}
</h6>
<p>
    {% if blog_post.allow_comments %}(<a href="#comments">{% spaceless %}
        {% blocktrans count blog_post.comments_count as comments_count %}1 comment{% plural %}{{ comments_count }} comments{% endblocktrans %}
    {% endspaceless %}</a>){% endif %}
</p>

{% if blog_post.featured_image %}
<p><img src="{{ MEDIA_URL }}{% thumbnail blog_post.featured_image 600 0 %}"></p>
{% endif %}

{% editable blog_post.content %}
{{ blog_post.content|richtext_filter|safe }}
{% endeditable %}

{% keywords_for blog_post as tags %}
{% if tags %}
{% spaceless %}
<ul class="unstyled tags">
    <li>{% trans "Tags" %}:</li>
    {% for tag in tags %}
    <li><a href="{% url blog_post_list_tag tag.slug %}">{{ tag }}</a></li>
    {% endfor %}
</ul>
{% endspaceless %}
{% endif %}

{% rating_for blog_post %}

{% set_short_url_for blog_post %}
<a class="btn small primary share-twitter" target="_blank" href="http://twitter.com/home?status={{ blog_post.short_url|urlencode }}%20{{ blog_post.title|urlencode }}">{% trans "Share on Twitter" %}</a>
<a class="btn small primary share-facebook" target="_blank" href="http://facebook.com/sharer.php?u={{ request.build_absolute_uri }}&amp;t={{ blog_post.title|urlencode }}">{% trans "Share on Facebook" %}</a>

{% if blog_post.allow_comments %}{% comments_for blog_post %}{% endif %}

{% endblock %}
