{% load i18n pages_tags %}

{% spaceless %}
{% if page_branch_in_menu %}

{% for page in page_branch %}
    {% if page.is_primary %}
        {% if forloop.first %}
            <ul>
        {% endif %}
        {% if page.in_menu %}
            <li><ul>
        {% endif %}
    {% endif %}

    {% if page.in_menu %}
        {% if forloop.first and not page.parent.in_menu and not page.is_primary %}
            <li><ul>
        {% endif %}
        <li {% if page.is_current_or_ascendant %}class="active"{% endif %}>
            <a href="{{ page.get_absolute_url }}">{{ page.title }}</a></li>
    {% endif %}

    {% if page.in_menu and page.has_children %}{% page_menu page %}{% endif %}

    {% if page.in_menu %}
        {% if forloop.first and not page.parent.in_menu and not page.is_primary %}
            </li></ul>
        {% endif %}
    {% endif %}

    {% if page.is_primary %}
        {% if page.in_menu %}
            </ul></li>
        {% endif %}
        {% if forloop.last %}
            </ul>
        {% endif %}
    {% endif %}

{% endfor %}

{% endif %}
{% endspaceless %}
