{% extends "pages/richtextpage.html" %}

{% block main %}
<!--
This template is provided as a custom template for the homepage, for
when it is configured as an editable page in the navigation tree. Feel
free to modify it.
-->
{{ block.super }}
{% endblock %}
