<!DOCTYPE html>
{% load pages_tags mezzanine_tags i18n %}
<html>
<head>

<meta http-equiv="Content-type" content="text/html; charset=utf-8">
<meta name="viewport" content="width=device-width">
<meta name="keywords" content="{% block meta_keywords %}{% endblock %}">
<meta name="description" content="{% block meta_description %}{% endblock %}">
<title>{% block meta_title %}{% endblock %}{% if settings.SITE_TITLE %} | {{ settings.SITE_TITLE }}{% endif %}</title>
<link rel="shortcut icon" href="{{ STATIC_URL }}img/favicon.ico">

{% ifinstalled mezzanine.blog %}
<link rel="alternate" type="application/rss+xml" title="RSS" href="{% url blog_post_feed "rss" %}">
<link rel="alternate" type="application/atom+xml" title="Atom" href="{% url blog_post_feed "atom" %}">
{% endifinstalled %}

{% compress css %}
<link rel="stylesheet" href="{{ STATIC_URL }}css/bootstrap.css">
<link rel="stylesheet" href="{{ STATIC_URL }}css/bootstrap.responsive.css">
<link rel="stylesheet" href="{{ STATIC_URL }}css/mezzanine.css">
{% ifinstalled cartridge.shop %}
<link rel="stylesheet" href="{{ STATIC_URL }}css/cartridge.css">
{% endifinstalled %}
{% block extra_css %}{% endblock %}
{% endcompress %}

{% compress js %}
<script src="{{ STATIC_URL }}mezzanine/js/{{ settings.JQUERY_FILENAME }}"></script>
<script src="{{ STATIC_URL }}js/bootstrap.min.js"></script>
<script>
$(function() {
    $('.middleinput:text, textarea').addClass('xlarge');
    $('.control-group label').addClass('control-label');
});
</script>
{% block extra_js %}{% endblock %}
{% endcompress %}
<!--[if lt IE 9]>
<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
<![endif]-->

{% block extra_head %}{% endblock %}

</head>
<body id="{% block body_id %}body{% endblock %}">

<div class="navbar">
<div class="navbar-inner">
<div class="container">
    <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
    </a>
    {% if settings.SITE_TITLE %}<a class="brand" href="/">{{ settings.SITE_TITLE }}</a>{% endif %}
    {% if settings.SITE_TAGLINE %}<p class="tagline">{{ settings.SITE_TAGLINE }}</p>{% endif %}
    <div class="nav-collapse">
        <form action="{% url search %}" class="navbar-search pull-right">
        <input class="search-query" placeholder="{% trans "Search" %}" type="text" name="q" value="{{ request.REQUEST.q }}">
        </form>
        {% page_menu "pages/menus/dropdown.html" %}
    </div>
</div>
</div>
</div>

<div class="container">

{% nevercache %}
{% for message in messages %}
<div class="alert alert-{{ message.tags }}" data-alert="alert">
<a class="close" href="#" onclick="$(this).parent().fadeOut('fast'); return false;">×</a>{{ message }}
</div>
{% endfor %}
{% endnevercache %}


<h1>{% block title %}{% endblock %}</h1>

<ul class="breadcrumb">
{% spaceless %}
{% block breadcrumb_menu %}{% page_menu "pages/menus/breadcrumb.html" %}{% endblock %}
{% endspaceless %}
</ul>

</div>

<div class="container">
<div class="row">

<div class="span2 left">
    {% block left_panel %}
    <div class="panel tree">{% page_menu "pages/menus/tree.html" %}</div>
    {% endblock %}
</div>

<div class="span7 middle">
    {% block main %}{% endblock %}
</div>

<div class="span3 right">
    {% nevercache %}
    {% include "includes/user_panel.html" %}
    {% endnevercache %}
    <div class="panel">
    {% block right_panel %}
    {% ifinstalled mezzanine.twitter %}
    {% include "twitter/tweets.html" %}
    {% endifinstalled %}
    {% endblock %}
    </div>
</div>

</div>
</div>

<footer>
<div class="container">
{% page_menu "pages/menus/footer.html" %}
<br style="clear:both">
<p>
    {% trans "Powered by" %}
    <a href="http://mezzanine.jupo.org">Mezzanine</a>{% ifinstalled cartridge.shop %},
    <a href="http://cartridge.jupo.org">Cartridge</a>{% endifinstalled %}
    {% trans "and" %}
    <a href="http://www.djangoproject.com">Django</a>
    <span class="separator">|</span>
    {% trans "Theme by" %} <a href="http://twitter.github.com/bootstrap/">Bootstrap</a>
    {% ifinstalled mezzanine.mobile %}
    <span class="separator">|</span>
    <a href="{% url set_device "mobile" %}?next={{ request.path }}">{% trans "View Mobile Site" %}</a>
    {% endifinstalled %}
</p>
</div>
</footer>

{% include "includes/footer_scripts.html" %}

</body>
</html>
