{% load i18n pages_tags %}

{% spaceless %}
{% if page_branch %}
{% for page in page_branch %}

	{% if page.is_primary and forloop.first %}
	<nav>
    <ul class="mobile-menu" data-role="listview" data-inset="true">
    {% endif %}

		{% if page.is_current_or_ascendant and not page.is_child %}
		{% page_menu page %}
		{% endif %}

		{% if page.is_child %}
		<li class="
			{% if forloop.first %} first{% endif %}
			{% if forloop.last %} last{% endif %}"
			id="mobile-menu-{{ page.html_id }}">
			<a href="{{ page.get_absolute_url }}" rel="external">{{ page.title }}</a>
		</li>
		{% endif %}

	{% if page.is_primary and forloop.last %}
	</ul></nav>
	{% endif %}
{% endfor %}
{% endif %}
{% endspaceless %}
