{% load i18n pages_tags %}

{% spaceless %}
{% if page_branch_in_menu %}
<ul class="nav nav-list navlist-menu-level-{{ branch_level }}">
  {% for page in page_branch %}
  {% if page.is_primary and forloop.first %}
  <li class="first{% if on_home %} active{% endif %}">
    <a href="{% url home %}">{% trans "Home" %}</a>
  </li>
  {% endif %}
  {% if page.in_menu %}
  <li class="
             {% if page.is_current %} active{% endif %}
             {% if not page.is_primary and forloop.first %} first{% endif %}
             {% if forloop.last %} last{% endif %}"
      id="tree-menu-{{ page.html_id }}">
    <a href="{{ page.get_absolute_url }}">{{ page.title }}</a>
    {# remove this if tag to always show all nav items #}
    {% if settings.PAGES_MENU_SHOW_ALL or page.is_current_or_ascendant %}
    {% if page.has_children %}{% page_menu page %}{% endif %}
    {% endif %}
  </li>
  {% endif %}
  {% endfor %}
</ul>
{% endif %}
{% endspaceless %}
