{% load i18n %}

<form id="editable-toolbar" method="POST" action="{% url admin:logout %}?{{ REDIRECT_FIELD_NAME }}={{ request.path }}">
    {% csrf_token %}
    <a id="editable-toolbar-toggle" href="#">&gt;&gt;</a>
    {% if page %}
    <a href="{{ page.get_admin_url }}">{% trans "Admin" %}</a>
    {% else %}
    <a href="{% url admin:index %}">{% trans "Admin" %}</a>
    {% endif %}
    <a id="editable-toolbar-logout" href="#">{% trans "Log out" %}</a>
</form>

<img id="editable-loading" src="{{ STATIC_URL }}mezzanine/img/loadingAnimation.gif" />

