{% extends "mobile/blog/blog_post_list.html" %}
{% load mezzanine_tags comment_tags keyword_tags i18n %}

{% block meta_title %}{{ blog_post.title }}{% endblock %}

{% block meta_keywords %}{% metablock %}
{% keywords_for blog_post as tags %}
{% for tag in tags %}{% if not forloop.first %}, {% endif %}{{ tag }}{% endfor %}
{% endmetablock %}{% endblock %}

{% block meta_description %}{% metablock %}
{{ blog_post.description }}
{% endmetablock %}{% endblock %}

{% block title %}
{% editable blog_post.title %}{{ blog_post.title }}{% endeditable %}
{% endblock %}

{% block main %}

<p>
    <em>
        {% trans "Posted by" %}
        <strong>
            {% with blog_post.user as author %}
            <a href="{% url blog_post_list_author author %}"
                >{{ author.get_full_name|default:author.username }}</a>
            {% endwith %}
        </strong>
        {{ blog_post.publish_date|timesince }} {% trans "ago" %}
    </em>
</p>

{% editable blog_post.content %}
{{ blog_post.content|safe }}
{% endeditable %}

{% keywords_for blog_post as tags %}
{% if tags %}
<div class="tags">
    {% trans "Tags" %}:
    <ul>
        {% for tag in tags %}
        <li><a href="{% url blog_post_list_tag tag.slug %}">{{ tag }}</a></li>
        {% endfor %}
    </ul>
</div>
{% endif %}

{% set_short_url_for blog_post %}
<div data-inline="true" class="share-links">
	{% trans "Share this on:" %}
    <a target=_"blank" href="http://twitter.com/home?status={{ blog_post.short_url|urlencode }}%20{{ blog_post.title|urlencode }}">Twitter</a>
    {% trans "or" %}
    <a target=_"blank" href="http://facebook.com/sharer.php?u={{ request.build_absolute_uri }}&t={{ blog_post.title|urlencode }}">Facebook</a>
</div>

{% if blog_post.allow_comments %}{% comments_for blog_post %}{% endif %}

{% endblock %}
