{% extends "mobile/pages/page.html" %}

{% load mezzanine_tags %}

{% block main %}{{ block.super }}

{% if request.GET.sent %}
    {{ page.form.response|safe }}
{% else %}
    {{ page.form.content|safe }}
    <form method="post" class="form"{% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
        {% nevercache %}
        <input type="hidden" name="referrer" value="{{ request.META.HTTP_REFERER }}">
        {% csrf_token %}
        {% endnevercache %}
        {{ form.as_p }}
        <input class="button" type="submit" value="{{ page.form.button_text }}">
    </form>
{% endif %}

{% endblock %}

