{% load i18n %}
<div class="dropdown-menu" style="display:none;">
<ul>
    <li><a href="{% url admin:index %}">{% trans "Dashboard" %}</a></li>
    {% for app in dropdown_menu_app_list %}
    <li>
        <a href="#">{% trans app.name %}</a>
        <ul class="dropdown-menu-menu">
        {% for model in app.models %}
            {% if model.perms.add or model.perms.change or model.perms.custom %}
            <li{% if forloop.first %} class="first"{% endif %}><a
                href="{{ model.admin_url }}{% if not model.perms.change and not model.perms.custom %}add/{% endif %}">{{ model.name }}</a></li>
            {% endif %}
        {% endfor %}
        </ul>
    </li>
    {% endfor %}
</ul>
{% if dropdown_menu_sites %}
<form action="{% url set_site %}">
<input type="hidden" name="next" value="{{ request.path }}">
<select name="site_id" onchange="this.form.submit();">
{% for site in dropdown_menu_sites %}
<option value="{{ site.id }}"
    {% if site.id == dropdown_menu_selected_site_id %} selected{% endif %}
    >{{ site }}</option>
{% endfor %}
</select>
</form>
{% endif %}
</div>
