
{% load twitter_tags i18n %}

{% tweets_default as tweets %}

{% if tweets %}
<h3>{% trans "Recent Tweets" %}</h3>
<ul class="unstyled tweets">
    {% for tweet in tweets %}
    <li>
        <img src="{{ tweet.profile_image_url }}" alt="">
        <a href="http://twitter.com/{{ tweet.user_name }}">@{{ tweet.user_name }}</a>
        {% if tweet.user_name != tweet.full_name %}<span class="name">@{{ tweet.full_name }}</span>{% endif %}
        {% if tweet.is_retweet %}
        <p><span class="recycle">&#x267B;</span>
        <img class="retweet" src="{{ tweet.retweeter_profile_image_url }}">
        <a href="http://twitter.com/{{ tweet.retweeter_user_name }}">@{{ tweet.retweeter_full_name }}</a></p>
        {% endif %}
        <div>{{ tweet.text|safe }}</div>
        <span class="timespan">{{ tweet.created_at|timesince }} {% trans "ago" %}</span>
    </li>
    {% endfor %}
</ul>
{% endif %}
