{% load pages_tags mezzanine_tags i18n %}
<!doctype html>
<html>
<head>

    <meta http-equiv="Content-type" content="text/html; charset=utf-8" />
    <meta name="keywords" content="{% block meta_keywords %}{% endblock %}" />
    <meta name="description" content="{% block meta_description %}{% endblock %}" />

    <meta name="viewport" content="initial-scale=1, maximum-scale=1">

    <title>{% block meta_title %}{% endblock %}</title>

    {% ifinstalled mezzanine.blog %}
    <link rel="alternate" type="application/rss+xml" title="RSS" href="{% url blog_post_feed "rss" %}" />
    <link rel="alternate" type="application/atom+xml" title="Atom" href="{% url blog_post_feed "atom" %}" />
    {% endifinstalled %}
    <link rel="apple-touch-icon" href="" />
    <link rel="stylesheet" href="{{ STATIC_URL }}css/global-mobile.css" type="text/css" />
    <link rel="stylesheet" href="http://code.jquery.com/mobile/1.0a2/jquery.mobile-1.0a2.min.css" />
    <script src="{{ STATIC_URL }}mezzanine/js/{{ settings.JQUERY_FILENAME }}"></script>
    <script src="http://code.jquery.com/mobile/1.0a2/jquery.mobile-1.0a2.min.js"></script>

    {% block extra_head %}{% endblock %}

</head>
<body id="{% block body_id %}{% endblock %}">
<div data-role="page" data-theme="d">
    <div data-role="header">
        <h1>{% block title %}{% endblock %}</h1>
        <a class="home" data-role="button" data-icon="star" href="{% url home %}">{% trans "Home" %}</a>
    </div>

    {% page_menu "pages/menus/mobile.html" %}

    <div data-role="content">
        {% block main %}{% endblock %}
    </div>

    <div data-role="footer">
        <div data-role="content" align="center">
        	{% include "mobile/includes/search.html" %}
            <p>{% trans "Powered by" %} <a href="http://mezzanine.jupo.org" rel="external">Mezzanine</a></p>
            <p><a href="{% url set_device "default" %}?next={{ request.path }}" rel="external">{% trans "View Full Site" %}</a></p>
        </div>
    </div>
</div>

{% include "mobile/includes/footer_scripts.html" %}

</body>
</html>

